automake-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH 6/8] Automake::Rule: rename: suffix_rule() -> next_in_suffix_chai


From: Stefano Lattarini
Subject: [PATCH 6/8] Automake::Rule: rename: suffix_rule() -> next_in_suffix_chain()
Date: Tue, 28 May 2013 11:45:38 +0200

* lib/Automake/Rule.pm (suffix_rule): Rename ...
(next_in_suffix_chain): ... like this.
(%suffix_rules): Adjust comments.
(@EXPORT): Adjust.
* automake.in (derive_suffix): Likewise.

Signed-off-by: Stefano Lattarini <address@hidden>
---
 automake.in          |  2 +-
 lib/Automake/Rule.pm | 11 ++++++-----
 2 files changed, 7 insertions(+), 6 deletions(-)

diff --git a/automake.in b/automake.in
index 76028ad..63d5bdf 100644
--- a/automake.in
+++ b/automake.in
@@ -5992,7 +5992,7 @@ sub derive_suffix ($$)
 
   while (!$extension_map{$source_ext} && $source_ext ne $obj)
     {
-      my $new_source_ext = suffix_rule ($source_ext, $obj);
+      my $new_source_ext = next_in_suffix_chain ($source_ext, $obj);
       last if not defined $new_source_ext;
       $source_ext = $new_source_ext;
     }
diff --git a/lib/Automake/Rule.pm b/lib/Automake/Rule.pm
index 9e2648d..b162865 100644
--- a/lib/Automake/Rule.pm
+++ b/lib/Automake/Rule.pm
@@ -29,7 +29,8 @@ use Automake::DisjConditions;
 require Exporter;
 use vars '@ISA', '@EXPORT', '@EXPORT_OK';
 @ISA = qw/Automake::Item Exporter/;
address@hidden = qw (reset register_suffix_rule suffix_rules_count suffix_rule
address@hidden = qw (reset register_suffix_rule suffix_rules_count
+              next_in_suffix_chain
              suffixes rules $KNOWN_EXTENSIONS_PATTERN
              depend %dependencies %actions register_action
              accept_extensions
@@ -123,8 +124,8 @@ only when keys exists in C<%dependencies>.
 
 use vars '%actions';
 
 # See comments in the implementation of the 'suffix_rule()' variable
 # for details.
 my %suffix_rules;
 
 # Same as $suffix_rules, but records only the default rules
@@ -348,14 +349,14 @@ sub reset()
   %actions = ();
 }
 
-=item C<suffix_rule ($ext1, $ext2)>
+=item C<next_in_suffix_chain ($ext1, $ext2)>
 
 Return the target suffix for the next rule to use to reach C<$ext2>
 from C<$ext1>, or C<undef> if no such rule exists.
 
 =cut
 
-sub suffix_rule ($$)
+sub next_in_suffix_chain ($$)
 {
   my ($ext1, $ext2) = @_;
   return undef unless (exists $suffix_rules{$ext1} and
@@ -123,8 +124,8 @@ only when keys exists in C<%dependencies>.
 use vars '%actions';
 
-# See comments in the implementation of the 'suffix_rule()' variable
-# for details.
+# See comments in the implementation of the 'next_in_suffix_chain()'
+# variable for details.
 my %suffix_rules;
 
-- 
1.8.3.rc3.8.g5e49f30




reply via email to

[Prev in Thread] Current Thread [Next in Thread]